@@ -8,7 +8,7 @@ import re
 
 __author__ = """Matt Burke"""
 __email__ = 'matttsburke@gmail.com'
-__version__ = '1.2.0'
+__version__ = '1.3.0'
 
 next_swipe = datetime.now
 visited_ids = []
@@ -152,6 +152,13 @@ def get_profile_data(id, like=False):
         pass
     if location:
         profile_data["location"] = location
+    try:
+        about = soup.find('div', {
+                         'class': "profile-section__txt profile-section__txt--about"}).text.rstrip('\n').strip()
+        profile_data["about"] = about
+    except:
+        pass
+
     try:
         for pers in soup.find_all('div', {'class': 'personal-info__item'}):
             label = fix_label(pers.find(
